############################################################################################################ ###
#=======================
# Code for Caissy et al. 2020 Biological Conservation  
# High conservation priority of range-edge plant populations not matched by habitat protection or research effort.
# (Script 1 of 2)
# Data analysis and figures except figure 1
#=======================

#=======================
# The Data required to run the code are
# # "data COSEWIC plants biology combined.csv"
# # "COSEWIC plant litsearch.csv"

# NOTE: For Windows users, we used the "quartz()" command to visualize our figures, which is only available to Mac users. Please use "windows()" where necessary.
#======================
############################################################################################################ ###

#Libraries----
  library(dplyr) #for data manipulation
  library(rcompanion) #for posthoc on Chisq test
  library(car) #for Anova command to see results in Anova-style tables with type 3 estimates
  library(emmeans) #for lsmeans command - posthoc tests for glm
  library(lattice) #for premlinary plots
  library(Matrix)
  library(lme4)
  library(MASS) #for negative binomial GLM
  library(visreg) #for plots
  library(rsq) #for plots
  library(lsmeans)
  library(sfsmisc) #to display nice logarithmic scales
  library(viridis) #for color blind friendly colors
  library(foreign)
  library(nnet)
  library(ggplot2)
  library(reshape2)
  library(scales)
  
#for citations
R.Version()
citation(package='rcompanion')
packageVersion('rcompanion')
citation(package='car')
packageVersion('car')
packageVersion('lsmeans')
citation(package='rgeos') #rgeos package was used for data extraction from maps
packageVersion('visreg')

## DATA: Conservation data ----  
getwd() 
setwd()

pporig <- read.csv("data COSEWIC plants biology combined.csv")
summary(pporig)
dim(pporig) 
#get rid of a few uneeded columns
ppall <- pporig
ppall$RJ.NOTES <- ppall$Date.Completed <- ppall$Report.downloaded.Yes.No. <- ppall$checked.by <- NULL
ppall$Literature.Notes <- ppall$SARA.Status.2017 <- ppall$SARA.Schedule.2017 <- NULL
ppall$loop_iterations <- ppall$Date.checked <-ppall$folder_name <-  NULL
ppall$taxon <- ppall$Taxon <- NULL #these are just 'plants' across the board
summary(ppall)


#get rid of columns doubled in the data
ppall$Common.Name <- NULL
summary(ppall)
#cases where Genus columns dont match - all mistakes are in 'genus' column
ppall[as.character(ppall$Genus) != as.character(ppall$genus),c('Genus','species','genus','species.1')]
#cases where species columsn dont match - all subspecies or typos
ppall[as.character(ppall$species) != as.character(ppall$species.1),c('Genus','species','genus','species.1')]
ppall$genus <- ppall$species.1 <- NULL
summary(ppall)
#cases where species has >1 population
ppall[ppall$Population!='' & !is.na(ppall$Population), 
      c('Scientific.Name','Genus','species','Population','Provinces.inRange',
        'COSEWIC.Status.2017','COSEWIC.status.2018',
        'NatureServe.Global.Rank.2018', 'NatureServe.Canadian.Rank.2018',
        'kept.in.quantitative.analysis','reason.for.removal')]
ppall$TwoPops <- as.factor(ifelse(ppall$Scientific.Name=='Eleocharis geniculata', 'twoENpops',  
                           ifelse(ppall$Scientific.Name=='Psilocarphus brevissimus' | ppall$Scientific.Name=='Smilax rotundifolia' | 
                                  ppall$Scientific.Name=='Solidago speciosa',  'twoDIFFpops', 'onepop')))
summary(ppall)
#1 taxon doesnt have even qualitative peripheral designation
ppall[is.na(ppall$Peripheral.Designation),] #Hackelia ciliata
table(ppall$reason.for.removal) #but notes say there are 2 with no status report
ppall[ppall$reason.for.removal=='no status report',] #Hackelia ciliata & Symphyotrichum sericeum (get rid of later)

#make sure already excluded extinct and extirpated taxa from all analyses
summary(ppall[,c('COSEWIC.Status.2017','COSEWIC.status.2018')])

#...Species Name (create name excluding variety/subspecies etc)
  ppall$Species.Name <- as.factor(paste(ppall$Genus, ppall$species, sep=' '))
  summary(ppall)
  levels(ppall$Species.Name) 
      
#...Type ---
  table(ppall$Type) #make sure no spaces / typos in names. not very many gymnosperms
  #create streamlined variable with fewer categories
  ppall$Type.all <- ppall$Type #save variable with all designations
  ppall$Type <- as.factor(ifelse(ppall$Type.all=='Dicot' | ppall$Type.all=='Eudicot', 'Dicot',
                          ifelse(ppall$Type.all=='Fern' | ppall$Type.all=='Quillwort', 'Pteridophyte', 
                                 as.character(ppall$Type.all))))
  table(ppall$Type.all, ppall$Type) 

#...Family ---
  levels(ppall$Family) #69 families

#...LifeHistory ---
  table(ppall$Life.History)
  #create streamlined variable with fewer categories
  ppall$LifeHist.all <- ppall$Life.History
  table(ppall$LifeHist.all, ppall$Life.History)
  ppall$Life.History <- as.factor(ifelse(ppall$LifeHist.all=='Annual' | ppall$LifeHist.all=='Biennial' | ppall$LifeHist.all=='Annual/Biennial', 'short-lived', 
                                 ifelse(ppall$LifeHist.all=='Perennial', 'long-lived', as.character('mixed'))))
  ppall$Life.History <- factor(ppall$Life.History, levels=c('short-lived', 'mixed', 'long-lived')) #put factor levels in logical order
  table(ppall$LifeHist.all, ppall$Life.History)

#...Growth Form ---
  table(ppall$Growth.Form) 
  #create streamlined variable with fewer categories
  ppall$Growth.all <- ppall$Growth.Form #save variable with all designations
  ppall$Growth.Form <- as.factor(ifelse(ppall$Growth.all=='herb' | ppall$Growth.all=='graminoid', 'herb','shrub/tree'))
  table(ppall$Growth.all, ppall$Growth.Form)

#...Habitat ---
  table(ppall$Habitat)
  #create streamlined variable with fewer categories
  ppall$Habitat.all <- ppall$Habitat #save variable with all designations
  ppall$Habitat <- as.factor(ifelse(grepl('aqua', ppall$Habitat.all), 'aquatic', 'terrestrial'))
  table(ppall$Habitat, ppall$Habitat.all)

#...Peripheral Designation (Y if taxon has only northernmost 20% or less of its range in Canada) ----
  names(ppall)
  summary(ppall$Peripheral.Designation.Qualitative) #qualitative designation from 1st submission
  ppall$PeripheralYN.SKN <- factor(ppall$Peripheral.Designation.Qualitative, levels=c('Y','N'))
  summary(ppall)
  ppall$Peripheral.Designation.Qualitative <- NULL
#...Calculate prop range in Canada ---
  ppall$prop_inCan <- round((ppall$can_areakm2 / ppall$total_areakm2), digits=3)
  summary(ppall[,c('prop_inCan','PeripheralYN.SKN')])
#make new designation based on quantitative range data and same 20% cutoff
  ppall$PeripheralYN.Quant.2 <- as.factor(
      ifelse(ppall$can_area/ppall$total_area < 0.2, "Y",
      ifelse(ppall$can_area/ppall$total_area >= 0.2,"N", NA)))
    #see how well they match (AH mannually fixed those where Qual designation was wrong)
    summary(ppall[c('PeripheralYN.SKN','PeripheralYN.Quant.2')])
    ppall[!is.na(ppall$PeripheralYN.Quant.2) & (ppall$PeripheralYN.SKN != ppall$PeripheralYN.Quant.2),
          c('Scientific.Name','PeripheralYN.SKN','PeripheralYN.Quant.2','prop_inCan')]
    #later will double check taxa with qualitative peripheral designation but no quantitative one (~line 229)
    #reorder so that 'Peripheral' before 'Non Peripheral'
    ppall$PeripheralYN.Quant.2 <- factor(ppall$PeripheralYN.Quant.2, levels=c('Y', 'N'))
#make new designation based on quantitative range data and 10% cutoff
  ppall$PeripheralYN.Quant.1 <- as.factor(
      ifelse(ppall$can_area/ppall$total_area <= 0.1, "Y",
      ifelse(ppall$can_area/ppall$total_area > 0.1,"N", NA)))
  summary(ppall[,c('PeripheralYN.Quant.2','PeripheralYN.Quant.1')])
  
#...can see which taxa are peripheral in Can but not at their northern range tip? Vancouver = 49.2 N, latitude Quebec City=46.8
  summary(ppall[,c('lat_min_can_range')])
  summary(ppall[ppall$PeripheralYN.SKN=='Y',c('lat_min_can_range')])
  hist(ppall$lat_min_can_range)
  hist(ppall$lat_min_can_range[ppall$PeripheralYN.SKN=='Y'])
  ppall[ppall$PeripheralYN.SKN=='Y' & !is.na(ppall$lat_min_can_range) & ppall$lat_min_can_range>49.1,
        c('Scientific.Name','Provinces.inRange','COSEWIC.status.2018','SKN.notes','Region.of.occurrence',"lat_min_can_range")]
  #4 taxa have southernmost part of their canadian range north of 49th parallel. Azolla = outlier pops, 
  
#...COSEWIC Assessment ---
  summary(ppall)
  summary(ppall[,c('COSEWIC.Status.2017','COSEWIC.status.2018')])
  #get rid of 2017 status and rename 2018 status
  ppall$COSEWIC.status <- ppall$COSEWIC.status.2018 #rename
  ppall$COSEWIC.Assessment.Date <- ppall$COSEWIC.Assessment.Date.2017 #rename
  ppall$COSEWIC.Status.2017 <- ppall$COSEWIC.Assessment.Date.2017 <- NULL
  
#...NatureServe ranks from 2018 ---
  #1=most threatened, 5=least threatened
  ppall$NSGlobal.Rank <- ppall$NatureServe.Global.Rank.2018
  ppall$NSCanadian.Rank <- ppall$NatureServe.Canadian.Rank.2018
  
#...create numeric COSEWIC designation (bigger number = less threatened)
  ppall$COSEWIC.num <- ifelse(ppall$COSEWIC.status == 'NR', 4,
                           ifelse(ppall$COSEWIC.status == 'SC', 3, 
                                  ifelse (ppall$COSEWIC.status == 'T', 2, 
                                          ifelse (ppall$COSEWIC.status == 'EN', 1, NA))))
    

#...Create streamlined final data set ----------------------------------------------------
  summary(ppall)
  names(ppall)
  #if species appears twice, it's because there are two populations
  allpops <- ppall[,c('common.name', 'Scientific.Name', 'Group', 'Type', 'Family', 'Genus','Species.Name',  #|taxonomy
                 'Life.History', 'Growth.Form', 'Habitat', 'Provinces.inRange', #|ecology
                 'COSEWIC.Assessment.Date', 'COSEWIC.status', 'COSEWIC.num',#COSEWIC-derived data
                 'NSGlobal.Rank', 'NSCanadian.Rank', #Natureserve data
                 'range.map.digitized.on.GIS', 'file', 'kept.in.quantitative.analysis', 'reason.for.removal', 'TwoPops', #map metadata
                 'PeripheralYN.SKN', 'PeripheralYN.Quant.2', 'PeripheralYN.Quant.1', #qualitative geographic data
                 'lat_min_can_range', 'can_areakm2', 'total_areakm2', 'prop_inCan', 'range_protected_area', 'total_humanpopulation')]
  allpops <- droplevels(allpops)
  summary(allpops)
  #give nicer names
  colnames(allpops) <- c('Common.name', 'Scientific.name', 'Group', 'Type', 'Family', 'Genus', 'Species.name', 
                 'Life.History', 'Growth.Form', 'Habitat', 'Provinces',
                 'COSEWIC.Assessment.Date', 'COSEWIC.status', 'COSEWIC.num',
                 'NSGlobal.Rank', 'NSCanadian.Rank', 
                 'range.map.digitized', 'file', 'inQuant.analyses', 'reason.for.removal', 'TwoPops', #map metadata
                 'Peripheral.Qual.2', 'Peripheral.Quant.2', 'Peripheral.Quant.1', #qualitative geographic data
                 'latmin_can', 'can_areakm2', 'total_areakm2', 'prop_inCan', 'protected_areaCankm2', 'total_humanpop')
  #order some variables
  allpops$COSEWIC.status <- factor(allpops$COSEWIC.status, levels=c('NR','SC','T','EN')) 
  summary(allpops)
  
  
# Reduce to the data sets we will use in analyses ###############################################################  
#get rid of cases with two populations with different COSEWIC statuses
  pp1 <- allpops[allpops$TwoPops!='twoDIFFpops',]
  pp1 <- droplevels(pp1)
  summary(pp1)
#get rid of extra line for Eleocharis geniculata
  pp1[pp1$TwoPops=='twoENpops',]
  pp1$Prov <- pp1$Provinces
  pp1$Provinces <- as.factor(ifelse(pp1$Species.name=='Eleocharis geniculata', 'BC, ON', as.character(pp1$Prov)))
  summary(pp1)
#create df alltaxa
  alltaxa <- pp1[pp1$reason.for.removal!='collapsed into one taxa',]
  dim(allpops); dim(pp1); dim(alltaxa) #down to 213 taxa
  alltaxa$TwoPops <- alltaxa$Prov <- NULL

#create df taxa.wmap (get rid of taxa with no COSEWIC report / map )
  table(alltaxa$reason.for.removal) #2 taxa have no report, 2 have no map
  alltaxa[alltaxa$reason.for.removal=='no status report',] #Hackelia ciliata & Symphyotrichum sericeum
  alltaxa[alltaxa$reason.for.removal=='no map in status report',] #Carex nebrascensis & Pedicularis furbishiae
#create df taxa.wmap
  taxa.wmap <- alltaxa[alltaxa$reason.for.removal!='no status report' & alltaxa$reason.for.removal!='no map in status report',]
  dim(allpops); dim(alltaxa); dim(taxa.wmap)
  taxa.wmap <- droplevels(taxa.wmap)
  summary(taxa.wmap)
  #create couple of new columns
  taxa.wmap$perc_inCan <- taxa.wmap$prop_inCan*100 #change proportion to percentage
  taxa.wmap$prop_Canprot <- taxa.wmap$protected_areaCankm2 / taxa.wmap$can_areakm2
  taxa.wmap$COSEWIC.numthreat <- ifelse(taxa.wmap$COSEWIC.status=='EN', 4, #get version where most threatened = highest #
                                    ifelse(taxa.wmap$COSEWIC.status=='T', 3,
                                           ifelse(taxa.wmap$COSEWIC.status=='SC', 2, 1)))
  #better mannually check the ones where there's no quantitative data 
  levels(taxa.wmap$reason.for.removal)
  test <- taxa.wmap[is.na(taxa.wmap$Peripheral.Quant.2) & taxa.wmap$reason.for.removal!='no status report',
            c('Scientific.name','Peripheral.Qual.2','Peripheral.Quant.2', 'reason.for.removal')]; test
  dim(test) #27 taxa
  #a few statuses changed 
  

#create dataframe with only taxa w quantitative maps
  ppQuant <- taxa.wmap[(taxa.wmap$inQuant.analyses=="Y"),] 
  ppQuant <- droplevels(ppQuant)

  
# Sample sizes #########################################################################################

#...Table 1: Sample sizes --------------------------  
#(a) populations with COSEWIC reports
dim(allpops)
#total
npop <- length(allpops$Scientific.name); npop
#at-risk
table(allpops$COSEWIC.status)
npop-23 #at-risk = total-NR=197
197/npop #90%
#cant get # peripheral as 4 taxa had no COSEWIC report /map

#(b) taxa with COSEWIC maps (excluding 3 taxa w 2 pops with diff COSEWIC statuses, 2 taxa w no report, 2 taxa w report but no map)
dim(taxa.wmap) #209 rows data
#total
ntax <- length(taxa.wmap$Scientific.name); ntax
#at-risk
table(taxa.wmap$COSEWIC.status)
ntax-20 #at-risk = total-NR=189
189/ntax
#peripheral
table(taxa.wmap$Peripheral.Qual.2) #peripheral = 165
165/ntax
  
#(c) taxa in (b) with NatureServe data
summary(taxa.wmap)
table(taxa.wmap$NSGlobal.Rank, taxa.wmap$NSCanadian.Rank)
#someone has NS rank of 1.5?
taxa.wmap[!is.na(taxa.wmap$NSGlobal.Rank) & (taxa.wmap$NSCanadian.Rank==1.5 | taxa.wmap$NSGlobal.Rank==1.5),] #Eriogonum flavum var aquilinum
taxa.wmap[is.na(taxa.wmap$NSGlobal.Rank) | is.na(taxa.wmap$NSCanadian.Rank),] #7 taxa
taxa.wmap$inNSanalyses <- as.factor(ifelse(is.na(taxa.wmap$NSGlobal.Rank) | is.na(taxa.wmap$NSCanadian.Rank), 'N', 'Y'))
#total
table(taxa.wmap$inNSanalyses) #202 taxa in, 7 excluded
nmap <- length(taxa.wmap$Species.name[taxa.wmap$inNSanalyses=='Y']); nmap
#at risk
table(taxa.wmap$COSEWIC.status, taxa.wmap$inNSanalyses)
nmap-16 #186 at-risk taxa
186/nmap
#peripheral
table(taxa.wmap$Peripheral.Qual.2[taxa.wmap$inNSanalyses=='Y']) #159 peripheral
159/nmap

#(d) taxa in (b) with digitizeable range map
summary(taxa.wmap[,c('Species.name','range.map.digitized','inQuant.analyses','reason.for.removal','Peripheral.Qual.2','Peripheral.Quant.2')])
#total
table(taxa.wmap$inQuant.analyses) #182 taxa in, 27 excluded
table(ppQuant$inQuant.analyses)
ndigmap <- length(ppQuant$Species.name); ndigmap #182 taxa with digitized map
#at risk
table(ppQuant$COSEWIC.status)
ndigmap-16 #166 at-risk taxa
166/ndigmap
#peripheral using 20% cutoff
table(ppQuant$Peripheral.Quant.2) #141 peripheral
ndigmapP <- length(ppQuant$Species.name[ppQuant$Peripheral.Quant.2=='Y']); ndigmapP #141 peripherl taxa
ndigmapP/ndigmap #77%
#peripheral using 10% cutoff
table(ppQuant$Peripheral.Quant.1) #127 peripheral
ndigmapP <- length(ppQuant$Species.name[ppQuant$Peripheral.Quant.1=='Y']); ndigmapP
ndigmapP/ndigmap #70%
#double check ones missing maps
ntax-ndigmap
table(taxa.wmap$reason.for.removal)

#... N Values in text ----
#... Abstract ---
summary(taxa.wmap)
  #look at data from at-risk species only
  test <- ppQuant[ppQuant$COSEWIC.status!='NR',] 
  test <- droplevels(test); summary(test)
  table(test$Peripheral.Quant.2) #132
  dim(test[(test$can_areakm2 / test$total_areakm2 < 0.2),]) #how many are both at-risk and peripheral? 132
  table(test$Peripheral.Quant.2) / length(test$Peripheral.Quant.2) #80% of atrisk taxa are peripheral (1 is peripheral into Alaska)
  median(test$can_areakm2 / test$total_areakm2)*100 #median % in Canada at risk sp = 1.8%
  mean(test$can_areakm2 / test$total_areakm2)*100 # mean % in Canada at risk sp = 19%
  median(ppQuant[ppQuant$COSEWIC.status=='EN',]$can_areakm2 / ppQuant[ppQuant$COSEWIC.status =='EN',]$total_areakm)*100 #median % endangered = 1%

#... caption Figure 1 ---
  #how many populations with COSEWIC statuses dont have digitizeable range maps?
  npop
  ndigmap
  npop-ndigmap

#... Results 1st paragraph  ---
#of 209 taxa with range maps, how many are both at-risk and peripheral? (ie using Qualitative assessment for27 taxa)
  #% at-risk taxa deemed peripheral
  test <- taxa.wmap[taxa.wmap$COSEWIC.status!='NR',]
  test <- droplevels(test)
  dim(test) #189 at-risk
  summary(test[,c('COSEWIC.status','Peripheral.Qual.2')]) #152 at risk peripheral taxa
  152/189 #80.4%
  151/189 #79.9% if dont include Micranthes with is at eastern range edge
#how many at-risk peripheral taxa occur only in ON or BC?
  table(test$Provinces, test$Peripheral.Qual.2)
  test$prov <- ifelse(test$Provinces=='ON' | test$Provinces=='BC', 'onlyONBC', 'other')
  table(test$prov, test$Peripheral.Qual.2) # numbers
  #peripheral at risk taxa
  104/(104+48) #68% of periph
  104+48 #151 peripheral at risk taxa
  #non peripheral at risk taxa
  7/(7+30) #21% of non periph
  
#_#########################################################################################
  
# ANALYSES Q1 - Q4 (everything but lit search) ############################################
  
#(Q1) Canadian vs Global NaturServe Status----------------------------------------------------
  
#...Analysis: Are Canadian vs global ranks more different for peripheral taxa? ---------------

#make dataframe with only taxa with NS ranks
  summary(taxa.wmap)
  NStaxa <- taxa.wmap[taxa.wmap$inNSanalyses=='Y',]
  NStaxa <- droplevels(NStaxa)
  summary(NStaxa)
  dim(taxa.wmap); dim(NStaxa) #should be 7 different
  
#compute difference between Canadian and global ranks
  NStaxa$NSdiff.CvG <- NStaxa$NSGlobal.Rank - NStaxa$NSCanadian.Rank
  summary(NStaxa$NSdiff.CvG) #ranges from 0 to 4, making it a very awkward response variable (numeric but few values)
  plot(NStaxa$NSdiff.CvG ~ NStaxa$Peripheral.Quant.2)
  plot(NStaxa$NSdiff.CvG ~ NStaxa$Peripheral.Qual.2) #should have more data
  
#does the global-canada rank difference differ between peripheral vs non-peripheral taxa?
  #include taxa whose peripherality we had to estimate visually
  wilcox.test(NSdiff.CvG ~ Peripheral.Qual.2, data=NStaxa, paired=F)
  #how many taxa does NS consider at risk in Canada (ranks 1-3)?
  NStaxa$NSCan <- ifelse(NStaxa$NSCanadian.Rank<4, 'atrisk.Can', 'NR.Can') #table too confusing to read if just Y or N
  NStaxa$NSGlob <- ifelse(NStaxa$NSGlobal.Rank<4, 'atrisk.glob', 'NR.glob')
  table(NStaxa$NSCan) #198 = at risk in Can
  table(NStaxa$NSCan, NStaxa$NSGlob) #of which 133 not at risk globally
  133/198 #67%
  table(NStaxa$NSCan[NStaxa$Peripheral.Qual.2=='Y'], NStaxa$NSGlob[NStaxa$Peripheral.Qual.2=='Y']) #of which 123 are peripheral
  
#...Figure 2. Can vs global NatConserv rank for peripheral vs non-peripheral taxa ---------------
  summary(NStaxa)
  #create broad categories of plants for plotting (herb, aquatic, woody)
  NStaxa$PlantCatFig <- as.factor(ifelse(NStaxa$Growth.Form=='herb' & NStaxa$Habitat=='terrestrial', 'TH', 
                                  ifelse(NStaxa$Habitat=='aquatic', 'A', 'W')))
  table(NStaxa$PlantCatFig, NStaxa$Life.History)
  
quartz(width=11, height=5.5)
  nf <- layout(matrix(c(5,5,0,1,1,4,2,2,4,3,0,0), nrow=3, ncol=4, byrow=F), widths=c(.05,1,1,.4), heights=c(1,1,.3)); layout.show(nf)
  par(mai=c(.2,.8,.8,0), oma=c(0, 0, 0, .5), bty='l') #mfcol draws plots by column
  cxp=1.8; lwdp=2
  abw=1.5; xl=1.9; yl=2.2 #line for xax label & yax label
  xlimCR=c(0.9,5.3); ylimCR=c(0.9,5); y=c(1,2,3,4,5)
  cxax=1.6; cxaxlab=1.3; cxpnlb=1.5
  colTH='chartreuse4'; colA='blue'; colW='brown'; #point colours reflect growth/realm
  pchL=1; pchS=0; pchM=2 #point shape reflects lifespan
  
  #Peripheral species
  plot(NSCanadian.Rank ~ NSGlobal.Rank, data=NStaxa, 
       xlab='', ylab="", xlim=xlimCR, ylim=ylimCR, col='white', las=1, cex.axis=cxax)
  abline(a=0, b=1, col='grey', lwd=abw)
  #colours and point shape vary by lifehistory and plant category so plot each group separately
  table(NStaxa$PlantCatFig[NStaxa$Peripheral.Qual.2=='Y'], NStaxa$Life.History[NStaxa$Peripheral.Qual.2=='Y'])
  #aquatic plants (blue)
  points(jitter(NSCanadian.Rank) ~ jitter(NSGlobal.Rank), 
         data=NStaxa[NStaxa$PlantCatFig=='A' & NStaxa$Life.History=='long-lived' & NStaxa$Peripheral.Qual.2=='Y',],
         pch=pchL, cex=cxp, lwd=lwdp, col=colA)
  points(jitter(NSCanadian.Rank) ~jitter(NSGlobal.Rank), 
         data=NStaxa[NStaxa$PlantCatFig=='A' & NStaxa$Life.History=='short-lived' & NStaxa$Peripheral.Qual.2=='Y',],
         pch=pchS, cex=cxp, lwd=lwdp, col=colA)
  points(jitter(NSCanadian.Rank) ~jitter(NSGlobal.Rank), 
         data=NStaxa[NStaxa$PlantCatFig=='A' & NStaxa$Life.History=='mixed' & NStaxa$Peripheral.Qual.2=='Y',],
         pch=pchM, cex=cxp, lwd=lwdp, col=colA)
  #terrestrial non-woody plants (green)
  points(jitter(NSCanadian.Rank) ~jitter(NSGlobal.Rank), 
         data=NStaxa[NStaxa$PlantCatFig=='TH' & NStaxa$Life.History=='long-lived'& NStaxa$Peripheral.Qual.2=='Y',],
         pch=pchL, cex=cxp, lwd=lwdp, col=colTH)
  points(jitter(NSCanadian.Rank)~jitter(NSGlobal.Rank), 
         data=NStaxa[NStaxa$PlantCatFig=='TH' & NStaxa$Life.History=='short-lived'& NStaxa$Peripheral.Qual.2=='Y',],
         pch=pchS,cex=cxp, lwd=lwdp, col=colTH)
  points(jitter(NSCanadian.Rank)~jitter(NSGlobal.Rank), 
         data=NStaxa[NStaxa$PlantCatFig=='TH' & NStaxa$Life.History=='mixed' & NStaxa$Peripheral.Qual.2=='Y',],
         pch=pchM, cex=cxp, lwd=lwdp, col=colTH)
  #terrestrial woody plants (brown; only long-lived)
  points(jitter(NSCanadian.Rank) ~jitter(NSGlobal.Rank), 
         data=NStaxa[NStaxa$PlantCatFig=='W' & NStaxa$Life.History=='long-lived' & NStaxa$Peripheral.Qual.2=='Y',],
         pch=pchL, cex=cxp, lwd=lwdp, col=colW)
  mtext('NatureServe Canadian threat rank', side=2, line=3.5, at=3, cex=cxaxlab)
  mtext('Taxa peripheral in Canada', side=3, line=-2.5, at=3, cex=cxpnlb)
  #
  #Non-peripheral species
  par(mai=c(0.2,0.5,0.82,0.1))
  plot(NSCanadian.Rank ~ NSGlobal.Rank, data=NStaxa, 
       xlab='', ylab='', yaxt='n', xlim=xlimCR, ylim=ylimCR, col='white', las=1,
       cex.axis = cxax)
  abline(a=0, b=1, col='grey', lwd=abw)
  #colours and point shape vary by Life.History and plant category so plot each group separately
  table(NStaxa$PlantCatFig[NStaxa$Peripheral.Qual.2=='N'], NStaxa$Life.History[NStaxa$Peripheral.Qual.2=='N'])
  #aquatic plants (blue) - no mixed
  points(jitter(NSCanadian.Rank) ~ jitter(NSGlobal.Rank), 
         data=NStaxa[NStaxa$PlantCatFig=='A' & NStaxa$Life.History=='long-lived' & NStaxa$Peripheral.Qual.2=='N',],
         pch=pchL, cex=cxp, lwd=lwdp, col=colA)
  points(jitter(NSCanadian.Rank)~jitter(NSGlobal.Rank), 
         data=NStaxa[NStaxa$PlantCatFig=='A' & NStaxa$Life.History=='short-lived' & NStaxa$Peripheral.Qual.2=='N',],
         pch=pchS, cex=cxp, lwd=lwdp, col=colA)
  #terrestrial non-woody plants (green)
  points(jitter(NSCanadian.Rank)~jitter(NSGlobal.Rank), 
         data=NStaxa[NStaxa$PlantCatFig=='TH' & NStaxa$Life.History=='long-lived' & NStaxa$Peripheral.Qual.2=='N',],
         pch=pchL, cex=cxp, lwd=lwdp, col=colTH)
  points(jitter(NSCanadian.Rank)~jitter(NSGlobal.Rank), 
         data=NStaxa[NStaxa$PlantCatFig=='TH' & NStaxa$Life.History=='short-lived' & NStaxa$Peripheral.Qual.2=='N',],
         pch=pchS, cex=cxp, lwd=lwdp, col=colTH)
  points(jitter(NSCanadian.Rank)~jitter(NSGlobal.Rank), 
         data=NStaxa[NStaxa$PlantCatFig=='TH' & NStaxa$Life.History=='mixed'& NStaxa$Peripheral.Qual.2=='N',],
         pch=pchM, cex=cxp, lwd=lwdp, col=colTH)
  #terrestrial woody plants (brown; only long-lived)
  points(jitter(NSCanadian.Rank)~jitter(NSGlobal.Rank), 
         data=NStaxa[NStaxa$PlantCatFig=='W' & NStaxa$Life.History=='long-lived' & NStaxa$Peripheral.Qual.2=='N',],
         pch=pchL, cex=cxp, lwd=lwdp, col=colW)
  axis(2, at=y,labels=FALSE)
  mtext("NatureServe Global threat rank", side=1, line=3.5,  at=0.5, cex =cxaxlab)
  mtext('Taxa not peripheral in Canada', side=3, line=-2.5, at=3, cex =cxpnlb)
  #
  #Legend
  par(mai = c(0,0,0.82,0))
  plot(c(1,6) ~ c(0,1), col='white', axes=F, xlab ='', ylab ='')
  leg1=4.5; cxlg=1.6; gap=.7; cxplg=cxp+.2; xp=.025
  points(xp, leg1, pch=pchL, cex=cxplg, lwd=lwdp);   text(0.1, leg1, 'Perennial', cex=cxlg, pos=4)
  points(xp, leg1-gap, pch=pchS, cex=cxplg, lwd=lwdp); text(0.1, leg1-gap, 'Annual/Biennial', cex=cxlg, pos=4)
  points(xp, leg1-gap*2, pch=pchM, cex=cxplg, lwd=lwdp); text(0.1, leg1-gap*2, 'Mixed', cex=cxlg, pos=4)
  #add symbols outside of R

  #...Fig2 caption --------
  dim(NStaxa) #202 taxa in analyses (shoudl match Table 1)
  summary(NStaxa[,c('Peripheral.Qual.2')]) 
  
  
#(Q2) Range area/prop range in Canada -------------------------------------------------
  summary(ppQuant)

#...(i) total area ~ COSEWIC threat rank -----
  median(ppQuant[ppQuant$COSEWIC.status!='NR',]$total_areakm2) #at-risk taxa -> 390521.2km2
  #global range differ among COSEWIC statuses?
  glm.totAreaR.nb <- glm.nb(round(total_areakm2) ~ COSEWIC.status, data=ppQuant)
      summary(glm.totAreaR.nb) 
      glm.totAreaR.nullnb <- glm.nb(round(total_areakm2) ~ 1, data=ppQuant)
      anova(glm.totAreaR.nb, glm.totAreaR.nullnb, test='Chisq') #P=0.057
      lsmeans(glm.totAreaR.nb, pairwise ~ COSEWIC.status) #one signif contrast: SC vs Th
      
  #...(ii) can area ~ COSEWIC status----
  median(ppQuant[ppQuant$COSEWIC.status!='NR',]$can_areakm2) #at-risk taxa -> 4598.0 km2
  #canadian range differ among COSEWIC statuses?
  glm.canAreaR.nb <- glm.nb(round(can_areakm2) ~ COSEWIC.status, data=ppQuant) 
      summary(glm.canAreaR.nb) #residuals of 233
      glm.canAreaR.nullnb <- glm.nb(round(can_areakm2) ~ 1, data=ppQuant)
      anova(glm.canAreaR.nb, glm.canAreaR.nullnb, test='Chisq')
      lsmeans(glm.canAreaR.nb, pairwise ~ COSEWIC.status) #NR > T = EN = SC (T vs E P=0.056)
  
  #...(iii) prop in Canada ~ COSEWIC status----
  median(ppQuant[ppQuant$COSEWIC.status!='NR',]$prop_inCan) #0.018
  #prop range in Canada differ among COSEWIC statuses?
  glm.percR.b <- glm(prop_inCan ~ COSEWIC.status, family=binomial, data=ppQuant)
      summary(glm.percR.b) #underdispersed. AIC=166, 119 on 178 df
  glm.percR.qb <- glm(prop_inCan ~ COSEWIC.status, family=quasibinomial, data=ppQuant)
      glm.percR.nullqb <- glm(prop_inCan ~ 1, family=quasibinomial, data=ppQuant)
      anova(glm.percR.qb, glm.percR.nullqb, test='Chisq')
      lsmeans(glm.percR.qb, pairwise ~ COSEWIC.status) #NRa SCa Tab ENb (SC v T P=0.056)
      #check results usin gnegative binomial
      glm.percR.nb <- glm.nb(round(prop_inCan*100) ~ COSEWIC.status, data=ppQuant)
      summary(glm.percR.nb) #underdispersed. ACI=1260, 205 on 178 df. AIC way higher so stick with qb

      
#...Figure 3 (3 panels figure)----
  colorNames <- c('#440154FF','#31688EFF','#35B779FF','#FDE725FF') #order = levels defined earlier (NAR, SC, T, E)
 
  quartz(width=5.6,height=7.8) 
  oma=c(1.2,1,1,1)
  oma=c(3,1,1,1) #not making any difference
  par <- par(mar=c(2.3,5,.1,2), oma=oma, las=1, family="Helvetica", bty="l", mfrow=c(3,1), cex.axis=1, cex=1, cex.lab=1, mgp=c(8,1,0))
  options(scipen = 999)

  plot.1 <- boxplot(total_areakm2 ~ COSEWIC.status, outline=F, 
                    log="y", xaxt="n", yaxt="n", ylim = c(0.99, 10^7), data=ppQuant)
        axis(2, labels=expression("Global range area (" ~ km^{2} ~ ")"), las=0, outer=F, at=5000, pos=-0.025, tick=F)
        eaxis(side = 2, at = c(1, 100, 10000, 10^6), at.small = F)
        axis(1, labels = F, at = c(1:4))
        #add coloured points
        stripchart(total_areakm2 ~ COSEWIC.status, vertical=T, data = ppQuant, 
                   method = "jitter", add = T, pch = 20, col=colorNames)
        #add significance labels
        y=10.3^7-10^6
        text(x=seq(1,4,by=1), y=rep(y,4), label=c('a','a','a','a'), cex=0.9, family="Helvetica")

  plot.2 <- boxplot(can_areakm2 ~ COSEWIC.status, outline=F, log="y", xaxt="n", yaxt="n", ylim=c(0.99, 1500000), data=ppQuant)
        axis(2, labels=expression("Canadian range area (" ~ km^{2} ~ ")"),las=0, outer = F, at = 1000, pos = -0.025, tick = F)
        eaxis(side = 2, at = c(1, 100, 10000, 10^6), at.small = F)
        axis(1, labels = F, at = c(1:4))
        stripchart(can_areakm2 ~ COSEWIC.status, vertical=T, data = ppQuant, 
                   method = "jitter", add = T, pch = 20, col=colorNames)
        #add significance labels
        text(x=seq(1,4,by=1), y=rep(10.8^6,4), label=c('a','b','b','b'), cex=0.9, family="Helvetica")
      
  plot.3 <- boxplot(100*prop_inCan ~ COSEWIC.status, outline=F, ylim=c(0,115), xaxt="n", ylab='', data=ppQuant)
        axis(2, labels="% of global range in Canada ", las=0, outer = F, at = 55, pos = -0.025, tick = F)
        axis(1, labels = F, at = c(1:4))
        stripchart(100*prop_inCan ~ COSEWIC.status, vertical = TRUE, data = ppQuant, 
                   method = "jitter", add = T, pch = 20, col=colorNames)
        #add significance labels
        text(x=seq(1,4,by=1), y=rep(110,4), label=c('a','a','ab','b'), cex=0.9, family="Helvetica")

        #sample size by COSEWIC rate (all three plots)
        table(ppQuant$COSEWIC.status)

  #...(iv) COSEWIC status ~ prop + can area----
    # Attempt using a multinomial model, not included in MS
    # summary(ppQuant)
    # relevel(ppQuant$COSEWIC.status, ref="NR")
    # multi.NRref <- multinom(formula = COSEWIC.status ~ prop_inCan + can_areakm2, data=ppQuant)
    # summary(multi.NRref)
    # Anova(multi.NRref, type='III') #significant for both can prop and can area
    # visreg(multi.NRref) 
    #figures to be included in Supp mat
    
    #what if just used numeric COSEWIC rank (ie conservation priority)
    table(ppQuant$COSEWIC.num, ppQuant$COSEWIC.status) #smaller numbers = more at risk (like NatServe) 
    table(ppQuant$COSEWIC.numthreat, ppQuant$COSEWIC.status) #higher numbers = more at risk 
    plot(COSEWIC.num ~ prop_inCan, data=ppQuant)
    plot(COSEWIC.num ~ can_areakm2, data=ppQuant)
    summary(ppQuant)

    sizeprop.qp <- glm(COSEWIC.numthreat ~ prop_inCan + can_areakm2, family=quasipoisson, data=ppQuant)
        summary(sizeprop.qp) #assume better
        visreg(sizeprop.qp, xvar='can_areakm2', by='prop_inCan', overlay=T)
        visreg(sizeprop.qp, xvar='prop_inCan', by='can_areakm2', overlay=T)
        Anova(sizeprop.qp, type='III')

        quartz(width=7, height=6)
        visreg(sizeprop.qp, xvar='prop_inCan', by='can_areakm2', overlay=T, scale='response', ylim=c(1,4),
               cex.axis=1.2, xlab='', ylab='', yaxt='n')
        axis(side=2, at=c(1,2,3,4), las=1, cex.axis=1.2)
        llab=2.8
        mtext(side=1, line=llab, text='Percentage of global range in Canada', cex=1.3)
        mtext(side=2, line=llab, text='COSEWIC numeric threat rank', cex=1.3)

    
#(Q3) people ~ COSEWIC status ----

#..data prep ---
summary(ppQuant)
ppQuant$humanperkm2 <- ppQuant$total_humanpop/ppQuant$can_areakm2
  
#...do more imperilled or more peripheral taxa have more people to deal with? ---
  glm.popDensR.fullnb <- glm.nb(round(humanperkm2) ~ COSEWIC.status * prop_inCan, data=ppQuant)
  glm.popDensR.nb <- glm.nb(round(humanperkm2) ~ COSEWIC.status + prop_inCan, data=ppQuant)
  anova(glm.popDensR.nb, glm.popDensR.fullnb, test='Chisq') #interaction NS
      summary(glm.popDensR.nb) #AIC = 1926
      #signif of peripherality
      glm.popDensR.noPnb <- glm.nb(round(humanperkm2) ~ COSEWIC.status, data=ppQuant)
      anova(glm.popDensR.nb, glm.popDensR.noPnb, test='Chisq') #NS
      #signif of imperillment
      glm.popDensR.noCnb <- glm.nb(round(humanperkm2) ~ prop_inCan, data=ppQuant)
      anova(glm.popDensR.nb, glm.popDensR.noCnb, test='Chisq') #super signif
      lsmeans(glm.popDensR.nb, pairwise ~ COSEWIC.status) #ENa Tb SCbc NAc
  
#...Figure 4 -------
table(ppQuant$COSEWIC.status) #for sample sizes
summary(ppQuant)
  
  quartz(width=6, height=3.55)
      mar=c(2,5,0,2); oma=c(1.5,1,1,1)
      par(las=1, family="Helvetica", bty="l", cex.axis=1, cex=1, cex.lab=1, mar=mar, oma=oma)
      ylim4 <- c(0.005, 7500)
      cax=.9
      
  plot.4 <- boxplot(humanperkm2 ~ COSEWIC.status, outline = F, xaxt="n", log="y", yaxt="n", ylim=ylim4, data=ppQuant)
      stripchart(humanperkm2 ~ COSEWIC.status, vertical=T, data=ppQuant, 
                 method="jitter", add=T, pch=20, col=colorNames)
      axis(2, labels = c(0.01, 0.1, 1, 10, 100, 1000), at = c(0.01, 0.1, 1, 10, 100, 1000))
      axis(2, labels = "Human population density in Canadian range", pos=-0.27, at=2.5, tick=F, las=0, cex.axis=1)
      axis(2, labels = "(people /"~ km^{2}~")", pos=0, at=5, tick = F, las=0)
      axis(1, labels = F, at = c(1:4))
      axis(1, labels=c('Assessed but','Special','Threatened','Endangered'), at=c(1:4), cex.axis=cax, pos=.005, tick=F)
      axis(1, labels=c('Not at risk','Concern','',''), at=c(1:4), cex.axis=cax, pos=.0023, tick=F)
      axis(1, labels=c('n = 16','n = 38','n = 42','n = 86'), at=c(1:4), cex.axis=cax, pos=.0008, tick=F)
      #add significance letters
      text(x=c(1,2,3,4), y=rep(8000,4), labels=c('c','bc','b','a'))

      
#(Q4) % range protected ~ COSEWIC status and peripherality ----
summary(ppQuant)
summary(ppQuant) #make sure prop variables range from 0 to 1
      
#...text results ---
    #median proportion Canadian range protected for at-risk species
    median(ppQuant[ppQuant$COSEWIC.status!='NR',]$prop_Canprot) #3.7%
    mean(ppQuant[ppQuant$COSEWIC.status!='NR',]$prop_Canprot) #10%
    #how many taxa have >50% of their Canadian range protected?
    ppQuant[ppQuant$prop_Canprot >=0.85 & ppQuant$COSEWIC.status!='NR',] #7 taxa, all SC
    ppQuant[ppQuant$prop_Canprot >=0.5 & ppQuant$COSEWIC.status!='NR',] #8 taxa, 7 SC & 1 EN

#... (quasi) binomial model --- 
  #check response variable
  #https://www.r-bloggers.com/interpreting-generalized-linear-models/
  hist(ppQuant$prop_Canprot, col='grey', breaks=20) #slightly bimodal, not obvious what best distribution is. certainly bounded at both ends, so probably quasi binomial?
  PropProt.b <- glm(prop_Canprot ~ COSEWIC.status*prop_inCan, family=binomial, data=ppQuant)
    summary(PropProt.b) #way underdispersed
    summary(residuals(PropProt.b)) #want deviance resids to be centred around 0 
  #including the COSEWIC x peripherality interaction
  PropProt.qb <- glm(prop_Canprot ~ COSEWIC.status*prop_inCan, family=quasibinomial, data=ppQuant)
    summary(PropProt.qb) 
    summary(residuals(PropProt.qb)) #dont change
  PropProt.noXqb <- glm(prop_Canprot ~ COSEWIC.status + prop_inCan, family=quasibinomial, data=ppQuant)
    anova(PropProt.qb, PropProt.noXqb, test='Chisq') #interaction v signif
    visreg(PropProt.qb, xvar='prop_inCan', by = "COSEWIC.status", layout=c(4,1)) #quick viz of slopes 
    lsmeans(PropProt.qb, pairwise ~ COSEWIC.status) #no signif contrasts
  #but do we care about that interaction? or do we just want to know each effect separately?
    Anova(PropProt.noXqb, type='III') #these = anova liklihood tests
    lsmeans(PropProt.noXqb, pairwise ~ COSEWIC.status, transform='response') 
    #prob protected = SCa NRab ENb THb
    visreg(PropProt.noXqb, xvar='COSEWIC.status') #logit boxplot 
    visreg(PropProt.noXqb, xvar='COSEWIC.status', scale='response') #backtransf boxplot 
    boxplot(prop_Canprot ~ COSEWIC.status, data=ppQuant)
    #effect of peripherality
    visreg(PropProt.noXqb, xvar='prop_inCan') #quick viz of slopes 
    visreg(PropProt.noXqb, xvar='prop_inCan', scale='response') #quick viz of slopes
    vprot.qb <- visreg(PropProt.noXqb, xvar='prop_inCan', scale='response', type='conditional', plot=F, partial=T)
    vprot.qb

#...Figure 5 new - 2 panels, no interaction ------
colB = adjustcolor('black', alpha=.5)
        
quartz(width=8.5, height=4)
    layout(matrix(c(1,2), nrow=1, ncol=2, byrow=F), widths=c(1,1))    
    oma=c(2,1.8,.5,0); mar=c(1.6,2,0,1); 
    ylim=c(0, 1.1)
    cxtk=.85; cxlb=1.1

#1st panel: protected by COSEWIC status. plot raw data as allows us to keep same format as before, & I think its what people will be most interested in (as opposed to conservation scaled by peripherality)      
par(family="Helvetica", bty="l", mar=mar, oma=oma)
boxplot(prop_Canprot ~ COSEWIC.status, outline=F, xaxt="n", yaxt='n', ylim=ylim, las=1, data=ppQuant)
      stripchart(prop_Canprot ~ COSEWIC.status, vertical=T, data=ppQuant, #rawdata points
                 method="jitter", add=T, pch=20, cex=.9, col=colorNames)
      axis(2, labels=F, at=seq(0,1,by=.2))
      mtext(side=2, at=seq(0,1,by=.2), text=c('0.0','0.2','0.4','0.6','0.8','1.0'), line=1, cex=cxtk, las=1)
      mtext(side=2, text="Proportion of Canadian range protected", line=2.6, las=0, cex=cxlb)
      axis(1, labels=F, at=c(1:4))
      lxlb=.4
      mtext(side=1, text=c('Assessed but','Special','Threatened','Endangered'), at=c(1:4), line=lxlb, cex=cxtk)
      mtext(side=1, text=c('Not at risk','Concern','',''), at=c(1:4), line=lxlb+.8, cex=cxtk)
      #mtext(side=1, text=c('n = 16','n = 38','n = 42','n = 86'), at=c(1:4), line=lxlb+1.7, cex=cxtk)
      lxlb2=lxlb+2.2; mtext(side=1, text='COSEWIC status', line=lxlb2, cex=cxlb)
      #add significance letters
      text(x=c(1,2,3,4), y=rep(1.1,4), labels=c('ab','a','b','b'))

plot(vprot.qb$fit$visregFit ~ vprot.qb$fit$prop_inCan, type='l', ylim=c(0,.65), xaxt='n',yaxt='n', ylab='n', las=1)
      polygon(y=c(vprot.qb$fit$visregLwr, rev(vprot.qb$fit$visregUpr)), 
              x=c(vprot.qb$fit$prop_inCan, rev(vprot.qb$fit$prop_inCan)), col='grey', border=NA)
      lines(vprot.qb$fit$visregFit ~ vprot.qb$fit$prop_inCan) #reinstate line
      points(y=vprot.qb$res$visregRes, x=vprot.qb$res$prop_inCan, pch=20, cex=.9, col=colB)
      axis(2, labels=F, at=seq(0,1,by=.2))
      mtext(side=2, at=seq(0,.6,by=.2), text=c('0.0','0.2','0.4','0.6'), line=1, cex=cxtk, las=1)
      axis(1, at=seq(0,1,by=.2), labels=NA)
      mtext(side=1, text=c('0.0','0.2','0.4','0.6','0.8','1.0'), at=seq(0,1,length.out=6), line=.5, cex=cxtk)
      mtext(side=1, text='Proportion of global range in Canada', line=lxlb2, cex=cxlb)
      
#_#########################################################################################

## DATA: Literature analysis #############################################################
    
#data structure: 1 row per study, only including studies with a conservation rank of 3 or 4 
#conservation relevance scored as 1=no relevance to conservation, 2=potential but no explicitly-stated relevance to conservation, 3=direct relevance to conservation issues /COSEWIC
conslit.full <- read.csv('COSEWIC plant litsearch.csv')
    head(conslit.full)
    names(conslit.full)
    summary(conslit.full$in.RJ.thesis) #Now almost doubled the original literature
    #get rid of conservation intent columns - decided not to use - and some extra journal info dont need
    conslit.full$cons.intent..1or2. <- conslit.full$cons.intent.notes <- conslit.full$in.RJ.thesis <- conslit.full$journal <- NULL
    conslit.full$provinces.of.occurrence <- conslit.full$Rj.peripheral..Y.N. <- conslit.full$peripheral.intent..0to2.<- NULL
    conslit.full$abstract <- conslit.full$SKN.peripheral..Y.N. <- conslit.full$vol.pg.article..  <- NULL #get rid of long column and abandonned column
    summary(conslit.full) 
    #clean names to make sure merge properly
    levels(conslit.full$Genus) #lots of spaces
    conslit.full$Genus <- as.factor(gsub(' ','', conslit.full$Genus)) #remove all spaces
    levels(conslit.full$species) #few to no species but clean anyway spaces
    conslit.full$species <- as.factor(gsub(' ','', conslit.full$species)) #remove all spaces
    #rename annoying columns
    names(conslit.full)[names(conslit.full)=='Rj.cons.relevance..1to3.']  <- 'cons.relevRJ'
    names(conslit.full)[names(conslit.full)=='SKN.cons.relevance..0to4.'] <- 'cons.relevSKN'
    names(conslit.full)[names(conslit.full)=='Can.pops...Y.N.']  <- 'Can.popsYN'
    names(conslit.full)[names(conslit.full)=='US.pops...Y.N.']  <- 'US.popsYN'
    levels(conslit.full$X.pops.sampled)
    names(conslit.full)[names(conslit.full)=='X.pops.sampled']  <- 'pops.sampled'
    summary(conslit.full)
    #why are there NAs for whether Can or US populations were sampled?
    conslit.full[is.na(conslit.full$Can.popsYN),
                 c('Genus','species','Can.popsYN', 'US.popsYN','range.coverage', 'notes.coverage','notes.design')] #cases where no access to paper

#conservation relevance rank ---
    table(conslit.full$cons.relevRJ, conslit.full$cons.relevSKN) #seems like either have rank from SKN or rank from RJ
    #cant get code to work in 1 step even though it should so do in two
    # step1 - combine two columns
    conslit.full$cons.relevcombo <- ifelse(!is.na(conslit.full$cons.relevSKN), conslit.full$cons.relevSKN, conslit.full$cons.relevRJ); 
    summary(conslit.full$cons.relevcombo) #should be no NAs (theres 1 NA - we remove it in a few lines)
    #step2 - combine ranks 3 and 4
    conslit.full$cons.relev <- ifelse(conslit.full$cons.relevcombo==4, 3, conslit.full$cons.relevcombo); 
    table(conslit.full$cons.relev, conslit.full$cons.relevSKN)
    summary(conslit.full)
    #still have 1 NA for Consrelev
    conslit.full[is.na(conslit.full$cons.relev),] #summary of another study - delete to not double count
    conslit2 <- conslit.full[!is.na(conslit.full$cons.relevcombo),]
    dim(conslit.full); dim(conslit2) #should only get rid of 1 line
    summary(conslit2) #no longer ny NAs for cons.relev
#get rid of redundant columns to minimize inconsistencies/errors
    conslit3 <- conslit2[,c('year.published','title','Genus','species',
                                'Can.popsYN', 'US.popsYN','range.coverage','cons.relev', 'cons.relevSKN')]
    summary(conslit3) #lots missing year of publication - #################################### ###
    dim(conslit3) #709 studies
    
    table(conslit3$paperID) #should all be 1 (unique ID)
    
    summary(conslit3)
    conslit3[conslit3$Genus=='Silene',]
    
#add in peripheral designation and COSEWIC status. only using at-risk spp so also get rid of NARs
    summary(conslit3)
    summary(taxa.wmap) #includes ones whose map not digitzeable
    taxaAR <- taxa.wmap[taxa.wmap$COSEWIC.status!='NR', 
                        c('Species.name','Genus','can_areakm2', 'total_areakm2','COSEWIC.status', 
                          "prop_inCan",'Peripheral.Qual.2', 'Peripheral.Quant.2', 'Peripheral.Quant.1')]
    taxaAR <- droplevels(taxaAR)
    summary(taxaAR)
    dim(taxaAR) #189 rows

#...merge literature & plant data ---
#(had to fix spelling for Isotria medeoloides, Sericocarpus rigidus, Lupinus lepidus, Astragalus...)
    names(taxaAR)
    names(conslit3)
    conslit3$Species.name <- as.factor(paste(conslit3$Genus, conslit3$species, sep=' '))
    summary(conslit3) #should be 0 NAs for cons.relev or Species.Name
    #merge
    lit.all <- merge(conslit3, taxaAR, by='Species.name', all=T)
    dim(conslit3); dim(lit.all) #709 studies but lit = 793
    summary(lit.all) 
    #check ones with COSEWIC status = NA
    lit.all[is.na(lit.all$COSEWIC.status),] 
    allpops[allpops$Genus=='Pedicularis' | allpops$Species.name=='Smilax rotundifolia',] 
    #no map for one, 2 pops with conflicting COSEWIC statuses for other
#create final data frame with only the 189 species with COSEWIC map and only studies with cons relevance of 3
    table(lit.all$cons.relev, lit.all$cons.relevSKN)
conslit <- lit.all[!is.na(lit.all$COSEWIC.status) & (is.na(lit.all$cons.relev) | lit.all$cons.relev==3),] 
    dim(conslit); dim(lit.all) 
    conslit <- droplevels(conslit)
    conslit$Genus.x <- conslit$Genus.y <- conslit$species <- NULL
    summary(conslit)
    

# (Q5) Conservation-relevant research effort on 189 at-risk plants ###################################  
    
#...for Text ---
summary(conslit)
#how many studies?
length(levels(conslit$title)) #657 studies
dim(conslit) #779
dim(conslit[!is.na(conslit$title),]) #695... so some studies must have data for >1 taxa

#how many studies included >1 taxa of interest?
n <- data.frame(table(conslit$title))
n[n$Freq > 1,]
nmult <- n[n$Freq > 1,]; nmult
dim(nmult) #32 studies 

#...data prep -------------------------
#create variables to count studies
  conslit$countstudies <- ifelse(is.na(conslit$title), 0, 1)
  conslit$countstudiesCan <- ifelse(is.na(conslit$title) | is.na(conslit$Can.popsYN) | conslit$Can.popsYN!='Y', 0, 1)
  conslit$countstudiesCanUS <- ifelse(!is.na(conslit$Can.popsYN) & conslit$Can.popsYN=='Y' & conslit$US.popsYN=='Y', 1, 0) 
  summary(conslit)
  levels(conslit$Species.name) #189 taxa
#create new df with 1 row per species
  lit.persp <- aggregate(conslit[c('countstudies','countstudiesCan','countstudiesCanUS')], 
                        by=conslit[c('Species.name','Peripheral.Qual.2','COSEWIC.status')], 
                        FUN=sum, na.rm=T) 
  summary(lit.persp) 
  dim(lit.persp) #should have only 1 row per species (189)
#create variable for 'has taxon been studied or not'
  lit.persp$studiedYN <- ifelse(lit.persp$countstudies==0, 0, 1)
  lit.persp$studiedCanYN <- ifelse(lit.persp$countstudiesCan==0, 0, 1)
  lit.persp$studiedCanUSYN <- ifelse(lit.persp$countstudiesCanUS==0, 0, 1)
    
  
#...Studies from anywhere in range -------------------------------------------- 
  table(lit.persp$studiedYN) 
  84/(84+105) #44% of at-risk species have not been studied at all
  
#...i) Are peripheral species more likely to have been studied at all? ---
  table(lit.persp$Peripheral.Qual.2) #152 peripheral, 37 not peripheral
  table(lit.persp$Peripheral.Qual.2, lit.persp$studiedYN)
  64/(64+88) #42% of peripheral at-risk taxa have not been studied
  20/(20+17) #54% of non-peripheral at-risk taxa have not been studied

  #binomial GLM
  studiedYN.b <- glm(studiedYN ~ Peripheral.Qual.2, family=binomial, data=lit.persp)
      summary(studiedYN.b) #fit meh
  studiedYN.qb <- glm(studiedYN ~ Peripheral.Qual.2, family=quasibinomial, data=lit.persp)
      Anova(studiedYN.b, type='III') #NS
      Anova(studiedYN.qb, type='III') #NS
      lsmeans(studiedYN.qb, ~ Peripheral.Qual.2, transform='response')
    
#...ii) Do peripheral species have more studies from anywhere in their range? ---
  studies.p <- glm(countstudies ~ Peripheral.Qual.2, family=poisson, data=lit.persp)
      summary(studies.p) #way overdispersed
  studies.nb <- glm.nb(countstudies ~ Peripheral.Qual.2, data=lit.persp)
      summary(studies.nb) #fit great
      #check significance
      studies.nullnb <- glm.nb(countstudies ~ 1, data=lit.persp)
      anova(studies.nb, studies.nullnb, test='Chisq') # studies/taxon doesnt differ significantly
    
      
#...Studied in Canada -------------------------------------------------  
    summary(conslit$Can.popsYN) #187 studies included Canadian populations
    #all at-risk taxa together
    table(lit.persp$studiedCanYN) 
    109/(109+80) #58% of at-risk species have not been studied at all in Canada
    lit.persp[lit.persp$countstudiesCan>5 & lit.persp$Peripheral.Qual.2=='Y',c(1:5)] #most studied =butternut w 14 studies

#...i) Are peripheral species more likely to have been studied in Canada? ---   
    table(lit.persp$Peripheral.Qual.2, lit.persp$studiedCanYN)
    88/(88+64) #58% of peripheral at-risk taxa have not been studied
    21/(21+16) #57% of non-peripheral at-risk taxa have not been studied
    #binomial GLM
    studiedCanYN.b <- glm(studiedCanYN ~ Peripheral.Qual.2, family=binomial, data=lit.persp)
        summary(studiedCanYN.b) #fit bit overdispersed
    #quasi binomial GLM (same results)
    studiedCanYN.qb <- glm(studiedCanYN ~ Peripheral.Qual.2, family=quasibinomial, data=lit.persp)
        Anova(studiedCanYN.qb, type='III')
    
#...ii) Do peripheral species have more studies from Canada? ---
    studiesCan.nb <- glm.nb(countstudiesCan ~ Peripheral.Qual.2, data=lit.persp)
        summary(studiesCan.nb) #fit good
        #check significance
        studiesCan.nullnb <- glm.nb(countstudiesCan ~ 1, data=lit.persp)
        anova(studiesCan.nb, studiesCan.nullnb, test='Chisq') # studies/taxon doesnt differ significantly
    
        
#...Studies that include both Can & US populations -------------------------------
#just realized that this question is not relevant for species with all or most of their range in Canada
#lets do for only plants with <half their range in Canada
  conslit.mostlynotCan <- conslit[is.na(conslit$prop_inCan) | conslit$prop_inCan<.5,]
     conslit.mostlynotCan <- droplevels(conslit.mostlynotCan)
     summary(conslit.mostlynotCan)
     levels(conslit.mostlynotCan$Species.name) #162 species have less than half their range in Canada
     levels(conslit.mostlynotCan$title) #536 studies on these species
     test <- conslit.mostlynotCan[conslit.mostlynotCan$countstudiesCanUS==1,]; test <- droplevels(test)
     dim(test) #34 taxa have been studied in Canada
     levels(test$title) #in 34 eparate studies
     34/536
     levels(test$Species.name) #studies are on 20 taxa
     
     
     lit.perspUSCA <- aggregate(conslit.mostlynotCan[c('countstudies','countstudiesCan','countstudiesCanUS')], 
                                by=conslit.mostlynotCan[c('Species.name','Peripheral.Qual.2','COSEWIC.status')], 
                                FUN=sum, na.rm=T) 
    summary(lit.perspUSCA) 
    dim(lit.perspUSCA) #162 species have <half their range in Canada
    lit.perspUSCA[lit.perspUSCA$countstudiesCanUS>0,] #only 20 species have been studied
    lit.perspUSCA[lit.perspUSCA$countstudiesCanUS>1,] #only 8 species have been studied more than once
    

#...Figure 6. Conservation relevant research on 194 at-risk plant taxa, studies from anywhere ----
#4 panel plot, shared y axes
  quartz(width=8, height=6.1)
      par(mfrow=c(2,2), oma=c(.5,3,2,.3), mar=c(4,1.6,1,1))
      breaks=c(0,1,seq(5,100,by=5)); breaks
      xtcks=seq(0,100,by=5); tck=-.02
      cxax=1.1; cxxlb=1.1; cxlb=1.2; 
      lylb=2.6; lxlb=2.4; ltoplb=.2; ltoplet=-.7 
    
    #top: studies anywhere in range on peripheral species
    table(lit.persp$Peripheral.Qual.2) #152 peripheral species, 37 non peripheral
    #who gets studied the most?
    lit.persp[lit.persp$countstudies>40,]
    
    xlim=c(2,98); ylim=c(1.8,49)
    x=lit.persp$countstudies[lit.persp$Peripheral.Qual.2=='Y']
    h = hist(x, breaks=(min(x)-1):(max(x))+0.5, plot=F)
    h$density = h$counts/sum(h$counts)*100
    plot(h, xlim=xlim, ylim=ylim, las=1, freq=FALSE, col='lightgrey', main='', xlab='', ylab='',
         cex.axis=cxax)
         rect(xleft=0-.5,xright=0+.5, ybottom=0,ytop=h$density[1], col='black') #overplot zero bar in black
         box(bty = 'l')
         axis(1, labels=F, at=xtcks, tck=tck)
        mtext('% of 152 species', side=2, line=lylb, cex=cxxlb)
        mtext('Species peripheral in Canada \n(n = 152 spp)', side=3, line=ltoplb, at=50, cex=cxlb)
        mtext('(A)', side=3, line=ltoplet, at=-19, cex=cxlb)
    #studies anywhere in range on non-peripheral species
    x=lit.persp$countstudies[lit.persp$Peripheral.Qual.2=='N']
    h = hist(x, breaks=(min(x)-1):(max(x))+0.5, plot=F)
    h$density = h$counts/sum(h$counts)*100
    plot(h, xlim=xlim, ylim=ylim, las=1, freq=FALSE, 
         col='lightgrey', main='', xlab='', ylab='', yaxt='n',
         cex.axis=cxax, cex.lab=cxlb)
        rect(xleft=0-.5,xright=0+.5, ybottom=0,ytop=h$density[1], col='black')
        box(bty = 'l')
        axis(2, labels =F, at=seq(0,60,by=10))
        axis(1, labels =F, at=xtcks, tck=tck)
        mtext('Species not peripheral in Canada \n(n = 37 spp)', side=3, line=ltoplb, at=50, cex=cxlb)
        mtext('% of 37 species', side=2, line=.8, cex=cxxlb)
    mtext('Conservation relevant studies per species', side=1, line=lxlb, at=0, cex=cxxlb)
    
    #studies on peripheral species w Canadian pops 
    sum(lit.persp$countstudiesCan) #187 studies on peripheral or not peripheral incl Can pops
    #who gets studied the most?
    lit.persp[lit.persp$countstudiesCan>5 & lit.persp$Peripheral.Qual.2=='Y',c(1:5)]
    lit.persp[lit.persp$countstudiesCan>5 & lit.persp$Peripheral.Qual.2=='N',c(1:5)]
    
    xlim=c(0,20); ylim=c(2.2,59)
    x=lit.persp$countstudiesCan[lit.persp$Peripheral.Qual.2=='Y']
    h = hist(x, breaks=(min(x)-1):(max(x))+0.5, plot=F)
    h$density = h$counts/sum(h$counts)*100
    plot(h, xlim=xlim, ylim=ylim, las=1, freq=FALSE, col='lightgrey', main='', xlab='', ylab='', cex.axis=cxax)
        rect(xleft=0-.5,xright=0+.5, ybottom=0,ytop=h$density[1], col='black')
        box(bty = 'l')
        mtext('% of 152 species', side=2, line=lylb, cex=cxxlb)
        mtext('(B)', side=3, line=ltoplet, at=-4.3, cex=cxlb)
    #studies anywhere in range on non-peripheral species
    x=lit.persp$countstudiesCan[lit.persp$Peripheral.Qual.2=='N']
    h = hist(x, breaks=(min(x)-1):(max(x))+0.5, plot=F)
    h$density = h$counts/sum(h$counts)*100
    plot(h, xlim=xlim, ylim=ylim, las=1, freq=F, col='lightgrey', main='', xlab='', ylab='', yaxt='n', cex.axis=cxax)
        rect(xleft=0-.5,xright=0+.5, ybottom=0,ytop=h$density[1], col='black')
        box(bty='l')
        axis(2, labels =F, at=seq(0,60,by=10))
    mtext('% of 37 species', side=2, line=.8, cex=cxxlb)
    mtext('Conservation relevant studies that include Canadian populations per species ', side=1, line=lxlb, at=0, cex=cxxlb)
    

#_#########################################################################################

# SUPPLEMENTARY INFO #####################################################################

#(Q1SI) Are NatureServe Canadian ranks and COSEWIC ranks consistent? -------------------
     summary(NStaxa) #created in Q1
     #create column for difference in ranking
     NStaxa$diff.NSCvCOSEWIC <- NStaxa$NSCanadian.Rank - as.numeric(NStaxa$COSEWIC.num)
     summary(NStaxa[,c('COSEWIC.num','COSEWIC.status','NSCanadian.Rank', 'diff.NSCvCOSEWIC')])
     
#...NatureServe & COSEWIC ranks differ? (YES - Fig S3a)? ---
     plot(jitter(NSCanadian.Rank) ~ jitter(COSEWIC.num), data=NStaxa)
     hist(NStaxa$NSCanadian.Rank, data=NStaxa, col='grey') #NS tend to be ranked as more endangered than cosewic
     hist(NStaxa$COSEWIC.num, data=NStaxa, col='grey')
     #paired wilcox test. does either agency rank taxa as more or less threatened overall? YES
     wilcox.test(NStaxa$NSCanadian.Rank, NStaxa$COSEWIC.num, paired=TRUE) 
     
    #does diff between NatureServe & COSEWIC ranks vary between periph and non periph taxa? (YES - Fig S3b)
     plot(diff.NSCvCOSEWIC ~ Peripheral.Qual.2, data=NStaxa, las=1, col='grey')
     plot(jitter(diff.NSCvCOSEWIC) ~ Peripheral.Qual.2, data=NStaxa, las=1, col='grey')
     wilcox.test(diff.NSCvCOSEWIC ~ Peripheral.Qual.2, data=NStaxa, paired=FALSE) 
     
#...Does answer to Q1 change if use COSEWIC instead of NScan ranks? ---
    #compute difference between Canadian and global ranks
    NStaxa$diff.CvG <- NStaxa$NSGlobal.Rank - NStaxa$NSCanadian.Rank
    summary(NStaxa$diff.CvG)
    plot(NStaxa$diff.CvG ~ NStaxa$Peripheral.Qual.2)
    #does the global-canada rank difference differ between peripheral vs non-peripheral taxa? (still yes)
    wilcox.test(diff.CvG ~ Peripheral.Qual.2, data=NStaxa, paired=F)

#(Q1SI definition of peripheral) ---------------------------------------------------------------------
    
#...Does answer to Q1 change if use only species with qualitative perpheral designtion? ---
    summary(NStaxa[,c('Peripheral.Qual.2','Peripheral.Quant.2','Peripheral.Quant.1')])
    159+43 #202 taxa in main analyses
    135+40 #175 taxa if use only those with digitized maps
    202-27
    wilcox.test(NSdiff.CvG ~ Peripheral.Qual.2, data=NStaxa, paired=F) #original
    wilcox.test(diff.CvG ~ Peripheral.Quant.2, data=NStaxa, paired=F)
#...Does answer to Q1 change if use only species with qualitative perpheral designtion & cutoff of 10%? ---
    wilcox.test(diff.CvG ~ Peripheral.Quant.1, data=NStaxa, paired=F)
    
    
#(Q2SI pre vs post SARA) -------

#add a column to ppQuant (SARAdate), if report done before 2002, 0, if after 2002 or in 2002, 1
ppQuant$SARA.Date <- as.factor(ifelse(ppQuant$COSEWIC.Assessment.Date < 2002, 'beforeSARA', 'afterSARA'))
  summary(ppQuant)
  
#...(i) total area ~ COSEWIC threat rank -----
    glm.totAreaRSARA.nb <- glm.nb(round(total_areakm2) ~ COSEWIC.status + SARA.Date, data=ppQuant)
        summary(glm.totAreaRSARA.nb) 
        glm.totAreaRSARA.noSnb <- glm.nb(round(total_areakm2) ~ COSEWIC.status, data=ppQuant)
        anova(glm.totAreaRSARA.nb, glm.totAreaRSARA.noSnb, test='Chisq') #global range of assessed taxa doesnt differ before or after SARA
        Anova(glm.totAreaRSARA.nb, type='III')
        
#...(ii) can area ~ COSEWIC status----
    glm.canAreaRSARA.nb <- glm.nb(round(can_areakm2) ~ COSEWIC.status + SARA.Date, data=ppQuant)
        summary(glm.canAreaRSARA.nb) #residuals of 240
        glm.canAreaRSARA.noSnb <- glm.nb(round(can_areakm2) ~ COSEWIC.status, data=ppQuant)
        anova(glm.canAreaRSARA.nb, glm.canAreaRSARA.noSnb, test='Chisq') #P = 0.07
        boxplot(round(can_areakm2) ~ SARA.Date,data=ppQuant) #taxa assessed after SARA have slightly SMALLER Can ranges
        lsmeans(glm.canAreaRSARA.nb, pairwise ~ SARA.Date)
        Anova(glm.canAreaRSARA.nb, type='III')
        
#...(iii) prop in Canada ~ COSEWIC status----
    glm.propRSARA.qb <- glm(prop_inCan ~ COSEWIC.status + SARA.Date, family=quasibinomial, data=ppQuant)
        glm.propRSARA.noSqb <- glm(prop_inCan ~ COSEWIC.status, family=quasibinomial, data=ppQuant)
        anova(glm.propRSARA.qb, glm.propRSARA.noSqb, test='Chisq') #better to use model without interaction
        Anova(glm.propRSARA.qb, type='III')

#...(iv) does peripherality matter if account for range area?
    sizepercwS.qp <- glm(COSEWIC.numthreat ~ perc_inCan*SARA.Date + can_areakm2*SARA.Date, family=quasipoisson, data=ppQuant)
    sizepercwS.noXqp <- glm(COSEWIC.numthreat ~ perc_inCan + can_areakm2 + SARA.Date, family=quasipoisson, data=ppQuant)
        anova(sizepercwS.qp, sizepercwS.noXqp, test='Chisq') #interactions don't matter
    sizeperc.qp <- glm(COSEWIC.numthreat ~ perc_inCan + can_areakm2, family=quasipoisson, data=ppQuant) #original
        anova(sizepercwS.qp, sizeperc.qp, test='Chisq') #w SARA & Xs better than without
        anova(sizepercwS.noXqp, sizeperc.qp, test='Chisq') #w SARA better than without
        Anova(sizepercwS.noXqp, type='III')
        lsmeans(sizepercwS.noXqp, pairwise ~ SARA.Date) #threat ranks were higher after SARA
        exp(1.16)
        exp(.902)
        visreg(sizeperc.qp, xvar='perc_inCan', by='can_areakm2', overlay=T, scale='response', ylim=c(1,4)) #original
        visreg(sizepercwS.qp, xvar='perc_inCan', by='can_areakm2', overlay=T, scale='response', ylim=c(1,4)) #slightly less steep

#(Q5SI definition of peripheral) -------
#create new df with 1 row per species, only taa w quant range map
  summary(conslit)
  conslit.quant <- conslit[!is.na(conslit$Peripheral.Quant.2),]
  lit.perspQ <- aggregate(conslit.quant[c('countstudies','countstudiesCan','countstudiesCanUS')], 
                        by=conslit.quant[c('Species.name','Peripheral.Quant.2','Peripheral.Quant.1','COSEWIC.status')], 
                        FUN=sum, na.rm=T) 
  summary(lit.perspQ) 
  dim(lit.perspQ) #should have only 1 row per species (166)
  #create variable for 'has taxon been studied or not'
  lit.perspQ$studiedYN <- ifelse(lit.perspQ$countstudies==0, 0, 1)
  lit.perspQ$studiedCanYN <- ifelse(lit.perspQ$countstudiesCan==0, 0, 1)

#...20% threshold but only studies with quantitative range map--------------------------------- 
#...Are peripheral species more likely to have been studied at all? ---
  studiedYNQ.qb <- glm(studiedYN ~ Peripheral.Quant.2, family=quasibinomial, data=lit.perspQ)
      Anova(studiedYNQ.qb, type='III') #NS
#...Do peripheral species have more studies from anywhere in their range? ---
  studiesQ.nb <- glm.nb(countstudies ~ Peripheral.Quant.2, data=lit.perspQ)
      studiesQ.nullnb <- glm.nb(countstudies ~ 1, data=lit.perspQ)
      anova(studiesQ.nb, studiesQ.nullnb, test='Chisq') 

#...Are peripheral species more likely to have been studied in Canada? ---
  studiedYNQCan.qb <- glm(studiedCanYN ~ Peripheral.Quant.2, family=quasibinomial, data=lit.perspQ)
      Anova(studiedYNQCan.qb, type='III') #NS
#...Do peripheral species have more studies from Canada? ---
  studiesQCan.nb <- glm.nb(countstudiesCan ~ Peripheral.Quant.2, data=lit.perspQ)
      studiesQCan.nullnb <- glm.nb(countstudiesCan ~ 1, data=lit.perspQ)
      anova(studiesQCan.nb, studiesQCan.nullnb, test='Chisq') 
      lsmeans(studiesQCan.nb, pairwise ~ Peripheral.Quant.2, transform='response') #NS but N almost > Y
    
#...10% threshold bu only studies with quantitative range map--------------------------------- 
#...Are peripheral species more likely to have been studied at all? ---
  studiedYNQ.qb <- glm(studiedYN ~ Peripheral.Quant.1, family=quasibinomial, data=lit.perspQ)
      Anova(studiedYNQ.qb, type='III') #NS
#...Do peripheral species have more studies from anywhere in their range? ---
  studiesQ.nb <- glm.nb(countstudies ~ Peripheral.Quant.1, data=lit.perspQ)
      studiesQ.nullnb <- glm.nb(countstudies ~ 1, data=lit.perspQ)
      anova(studiesQ.nb, studiesQ.nullnb, test='Chisq') 

#...Are peripheral species more likely to have been studied in Canada? ---
  studiedYNQCan.qb <- glm(studiedCanYN ~ Peripheral.Quant.1, family=quasibinomial, data=lit.perspQ)
      Anova(studiedYNQCan.qb, type='III') #NS
#...Do peripheral species have more studies from Canada? ---
  studiesQ.1Can.nb <- glm.nb(countstudiesCan ~ Peripheral.Quant.1, data=lit.perspQ)
      studiesQ.1Can.nullnb <- glm.nb(countstudiesCan ~ 1, data=lit.perspQ)
      anova(studiesQ.1Can.nb, studiesQ.1Can.nullnb, test='Chisq') 
      lsmeans(studiesQ.1Can.nb, pairwise ~ Peripheral.Quant.1, transform='response') #N > Y

      