#=======================
# Code for Caissy et al. 2020 Biological Conservation  
# High conservation priority of range-edge plant populations not matched by habitat protection or research effort.
# (Script 2 of 2)
# Data extraction from maps
#=======================

#=======================
# Output: 
# # "df.area.csv", "df.population.csv" & "df.prot.area.csv", which contain the map data (except NAs) included in "data COSEWIC plants biology combined.csv" columns 
#=======================

#=======================
# The Data required to run the code are
# # "data_COSEWIC.csv" file that stores information from assessment reports on species that COSEWIC has assessed.
# # Distribution maps of canadian terrestrial plants assessed by COSEWIC.
# # "shp_america" & "shp_canada", continent shapefiles saved as rds files in this context.
# # "ilot.shp", Statistics Canada census data from 2016. Consist of a combined shp and csv file saved as a rds file in this context.
# # "shp_PA_Canada", from CARTS 2017 dataset of federally protected area in Canada, & "shp_PA_Quebec", from Ministère de l'Environnement et de Lutte contre les Changements Climatiques du Québec dataset of 2017 Quebec protected areas, both saved as rds datafiles in this context

# # NOTE 1. geographical datasets from different sources are not archived to avoid violating data sharing policies.
# # NOTE 2. geographical datasets used in this script are heavy and processing in R may take time depending on the machine memory.
#======================

#### Libraries ####
library(readr)
library(readxl)
library(sp) 
library(rgeos)
library(rgdal)
library(raster)

setwd()
getwd()


#### upload the dataset ####
#folder containing COSEWIC data for all groups and subset it to plants only for which I have the maps
  df.status <- read.csv("COSEWIC_data.csv", na.strings = "")
    df.status.subset <- df.status[df.status$taxon == "plants",]
    df.status.subset <- df.status.subset[is.na(df.status.subset$file) == FALSE,]
    #add loop iterations number to be able to locate any problems during the looping process and correct it later on
    df.status.subset$loop_iterations <- 1:nrow(df.status.subset)
    #clean the environment by removing df.status which will not be required for the remaining parts of the code
    rm(df.status)

#..Q1 & 2----
####......initialize variables for loop to work correctly using df.status.subset####

  i = 1
  #create an empty dataframe to enter my area data later on
  df.area <- NULL
  #variable to be able to change my projection to the equal-area projection Mollweide later in the code
  PROJ <- "+proj=moll +lon_0=0 +x_0=0 +y_0=0 +datum=WGS84 +units=m +no_defs"
  shp.canada <- readRDS("shp_canada", refhook = NULL)
  shp.america<- readRDS("shp_america", refhook = NULL)


####...loop to do all my calculations####
  for(i in 1:nrow(df.status.subset)){
    print(i) #help me know the progression of the loop in the console
    
    #initialize variables so that I can retrieve my range shapefile in the "COSEWIC GIS plants" folder
      folder <- as.character(df.status.subset[i, "folder_name"])
      range <- as.character(df.status.subset[i,"file"])
      dsn <- paste(getwd(),folder, sep = "/")
    
    #get my shapefiles
      shp.range <- readOGR(dsn=dsn,range)
      #intersect it with American continent to remove major water plans and uniformize the ranges built by COSEWIC (I know none of my plants had populations out of the American continent)
      shp.range <- intersect(shp.america, shp.range)
      
      if(is.null(shp.range) == FALSE) {
        #this if statement is to make sure I don't have an empty object due to an error during the intersection of shp.range with shp.america
       
         #global range coordinates -> I ended up ont using the coordinates in my analysis
            ext.g <- t(sapply(1:length(shp.range), function(i) as.vector(extent(shp.range[i,]))))
            colnames(ext.g) <- c('xmin', 'xmax', 'ymin', 'ymax')
            xmin.g <- min(ext.g[,1], na.rm=T)
            xmax.g <- max(ext.g[,2], na.rm=T)
            ymin.g <- min(ext.g[,3], na.rm=T)
            ymax.g <- max(ext.g[,4], na.rm=T)
        
        #global range area
          shp.range <- spTransform(shp.range, CRSobj = PROJ) #change projection to Mollweide (equal area projection) -> did not calculate coordinates with that one because is in meters and not in degrees 
          total.area <- gArea(shp.range)
          total.area <- total.area/1000^2 #now in km^2
          
        #canadian range calculations
          #had to reload it so that it would be projected the right way to intersect with can.range (shp without the same projection cannot intersect)
          shp.range <- readOGR(dsn=dsn,range)
          can.range <- intersect(shp.canada, shp.range)
        
          if(is.null(can.range) == FALSE) {
          #no intersection could have been due to an extirpated species or an error in the intersection
            
            #canadian range coordinates
              ext.c <- t(sapply(1:length(can.range), function(i) as.vector(extent(can.range[i,]))))
              colnames(ext.c) <- c('xmin', 'xmax', 'ymin', 'ymax')
              xmin.c <- min(ext.c[,1], na.rm=T)
              xmax.c <- max(ext.c[,2], na.rm=T)
              ymin.c <- min(ext.c[,3], na.rm=T)
              ymax.c <- max(ext.c[,4], na.rm=T)
            
            #canadian area
              can.range <- spTransform(can.range, CRSobj = PROJ) #change projection to Mollweide (equal area projection) -> did not calculate coordinates with that one because is in meters and not in degrees
              can.area <- gArea(can.range)
              can.area <- can.area/1000^2     #now in km^2
          }
          if(is.null(can.range) == TRUE) {
            #this if statement is the way I decided to write my script so that I can verify later why the intersection command failed with shp.canada: was the species extirpated or the shapefile corrupted, etc. 
            
            can.area = 0
            xmin.c = NA
            xmax.c = NA
            ymin.c = NA
            ymax.c = NA
          }
      } else {
        #this if statement catches up cases where the american continent does not overlap with the species range. It never occurred, but had to put it in case.
        
        total.area = NA
        can.area = NA
        xmin.g = NA
        xmax.g = NA
        ymin.g = NA
        ymax.g = NA
        xmin.c = NA
        xmax.c = NA
        ymin.c = NA
        ymax.c = NA
        
      }
      
      #write in the table
      df.area<-rbind(df.area, data.frame(loop_iterations = i, folder_name = folder, can_area = can.area, 
                                         total_area = total.area,
                                         x_min_global_range = xmin.g, x_max_global_range = xmax.g,
                                         y_min_global_range = ymin.g, y_max_global_range = ymax.g,
                                         x_min_can_range = xmin.c, x_max_can_range = xmax.c,
                                         y_min_can_range = ymin.c, y_max_can_range = ymax.c))
      
      i = i+1 #put at the end of the loop
  }

  write.csv(df.area, "df.area.csv")

#..Q3 ----
  ####.......initialize variablesy####
  dsn.stat.can <- getwd()
  shp.ilot <- readRDS("shp_ilot", refhook = NULL)
  shp.ilot <- gBuffer(shp.ilot, byid = TRUE, width = 0) #buffer used to smoother polygon line
  
  #initilization of variables necessary to the loop good functioning
  i = 1
  df.population = NULL
  
  #...loop to get pop density for all plant taxa----
    for(i in 1:nrow(df.status.subset)){
      print(i) #help me know the progression
      if(i<=nrow(df.status.subset)){
        #initialize variables
        folder <- as.character(df.status.subset[i, "folder_name"])
        range <- as.character(df.status.subset[i,"file"])
        dsn <- paste(getwd(),folder, sep = "/")
        
        #get my shapefiles
        #range
        shp.range <- readOGR(dsn=dsn,range)
        #change projection to Mollweide
        shp.range <- spTransform(shp.range, CRSobj = PROJ)
        gBuffer(shp.range, byid = TRUE, width = 0)
        #intersect range with stat can dataset so that you get the whole population within the range later on
        stat.range <- intersect(shp.ilot, shp.range)
        if(is.null(stat.range) == FALSE) {#prevent when the range do not intersect with Canada
          population.number <- as.numeric(as.character(stat.range$censusdata))
          total.pop <- sum(population.number,na.rm = T) #calculate total population
        }
        if(is.null(stat.range)==TRUE) {
          total.pop = NA
        }
        #put it in a table
        df.population <- rbind(df.population, data.frame(loop_iterations = i, folder_name = folder, total_population = total.pop))
      }
      #to not get stuck in an infinite loop!
      i = i+1
    }
  
  write.csv(df.population, "df.population.csv")
  
#..Q4----
  
  ####......initialize variables for loop to work correctly using df.status.subset####
  #dummy variable to be able to work through the dataframe in a loop
  i = 1
  #name a variable with the same name as the first folder in my list of folders
  folder <- as.character(df.status.subset[i, "folder_name"])
  range <- as.character(df.status.subset[i,"file"])
  #create an empty dataframe to enter my area data later on
  df.prot.area <- NULL
  #variable to be able to change my projection to the equal-area projection Mollweide later in the code
  PROJ <- "+proj=moll +lon_0=0 +x_0=0 +y_0=0 +datum=WGS84 +units=m +no_defs"
  ####quick re-upload of the shp with right projection + buffered with a 0 km width to smooth the polygon edges
  shp.PA_Canada <- readRDS("shp_PA_Canada", refhook = NULL)
  shp.PA_Quebec<- readRDS("shp_PA_Quebec", refhook = NULL)
  
  #..loop to get protected areas----
  for(i in 1:nrow(df.status.subset)){
    #re-initialize variables at each steps
    print(i) #so I can now where I'm at when the loop iterates
    folder <- as.character(df.status.subset[i, "folder_name"])
    range <- as.character(df.status.subset[i,"file"])
    dsn <- paste(getwd(),folder, sep = "/")
    
    #intersect with Canada shp to remove major water plans and increase approximation of area accuracy
    shp.range <- readOGR(dsn=dsn,range)
    int.can.range <- intersect(shp.canada, shp.range)
    
    #list of conditions
    
    if(is.null(int.can.range) == FALSE) { #1. verify if my species range overlaps with Canada & then intersect it with PA shp
        int.can.range <- spTransform(int.can.range, CRSobj = PROJ) 
        int.PA_Canada <- intersect(int.can.range,shp.PA_Canada)
        int.PA_Quebec <- intersect(int.can.range, shp.PA_Quebec)
        if(is.null(int.PA_Canada) == TRUE && is.null(int.PA_Quebec) == TRUE) { #1.1.  make sure my species range does not overlap with any PA, 
          #if so, put PA overlap values to 0 in df.prot.area
          overlap.PA = 0
        } else if (is.null(int.PA_Canada) == TRUE && is.null(int.PA_Quebec) == FALSE) {#1.2. verify if my species range overlaps with Qc PA only, if so calculate PA overlap from int.PA_Quebec only
          overlap.PA = gArea(int.PA_Quebec)/1000^2                 
          
        } else if (is.null(int.PA_Canada) == FALSE && is.null(int.PA_Quebec) == TRUE) { #1.3. verify if my species range overlaps with Canada PA only, if so calculate PA overlap from int.PA_Canada only
          
          overlap.PA = gArea(int.PA_Canada)/1000^2                                     
        } else{  #1.3. verify if my species range overlap with both PA shps, if so, sum both overlaps areas
          int.PA <- intersect(int.PA_Quebec, int.PA_Canada)
            if(is.null(int.PA) == FALSE){
              overlap.PA = (gArea(int.PA_Canada) + gArea(int.PA_Quebec))/1000^2 - gArea(int.PA)/1000^2
            }
            if(is.null(int.PA)==TRUE){
              overlap.PA = (gArea(int.PA_Canada) + gArea(int.PA_Quebec))/1000^2
            }
        }
    }
    if(is.null(int.can.range) == TRUE) { #2. verify whether my species range overlap with Canada,if not, then put PA overlap values to NA
      overlap.PA = NA
    }
    
    df.prot.area<-rbind(df.prot.area, data.frame(loop_iterations = i, folder_name = folder,
                                                 range_protected_area = overlap.PA))
    i = i +1
  }
  
  #upload csv file
  write.csv(df.prot.area, "df.prot.area.csv")
  
  

  
